# Launart - Launch for Graia Project

[![PyPI](https://img.shields.io/pypi/v/launart)](https://pypi.org/project/launart)
[![Docs](https://img.shields.io/badge/文档-here-blue)](https://graia.readthedocs.io/other/launart/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![codecov](https://codecov.io/gh/GraiaProject/launart/branch/master/graph/badge.svg?token=MW5U3JYXRA)](https://codecov.io/gh/GraiaProject/launart)
[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://pdm.fming.dev)

`Launart` 是实际实现了 `Launch API`, 即统一的应用实例启动时部件管理; 本部件为 Graia Project 内部使用.

在应用实例装载 `richuru` 后可获得更加缤纷多彩的控制台输出.